
// Given a koIPart, invoke it (do it's "double-click" action) through
// whatever code path is appropriate for that part -- i.e. snippets
// get inserted, commands get run, etc.
//
function part_invokePart(part) {
    switch (part.type) {
        case 'URL':
            browse_OpenUrlInDefaultBrowser(part.value);
            break;
        case 'command':
            Run_CommandPart(part);
            break;
        case 'snippet':
            Snippet_insert(part);
            break;
        case 'file':
            open_openURI(part.url);
            break;
        case 'template':
            gViewMgr.doFileNewFromTemplate(part.value);
            break;
        case 'DirectoryShortcut':
            OpenDirectoryShortcut(part)
            break;
        case 'macro':
            macro_executeMacro(part)
            break;
        default:
            dialog_alert("Don't know how to launch items of type " + part.type);
            break;
    }}

// Given the numeric ID of a part, find it and invoke it.
function part_invokePartById(id) {
    try {
        var part = part_findPartById(id);
        if (!part) {
            gProjectManager.log.error("Couldnt' find part with id: " + id);
            return;
        }
        part_invokePart(part);
    } catch (e) {
        gProjectManager.log.error(e);
    }
}

// Given a numeric id, look in the projects and toolboxes until you find
// the first part with that id (the id allocation scheme guarantees there
// will be at most one) and return it.  Return null on failure to find such
// a part.
var gPartSvc = Components.classes["@activestate.com/koPartService;1"].
        getService(Components.interfaces.koIPartService);

function part_findPartById(id) {
    var part;
    part = gPartSvc.getPartById(id);
    if (!part) {
        gProjectManager.log.error("Couldn't find part with id: " + id);
    }
    return part;
}

function _getPartURL(part) {
    if (part.hasAttribute('url')) {
        // Is it a project or a folder?
        var url = part.getStringAttribute('url')
        var pathSvc = Components.classes["@activestate.com/koOsPath;1"]
                                .getService(Components.interfaces.koIOsPath);
        var dirname = uriparse_URIToLocalPath(url);
        if (part.type == 'project') {
            dirname = pathSvc.dirname(dirname);
        }
        return dirname;
    } else if (part.parent) {
        return _getPartURL(part.parent);
    }
    return null;
}

function part_ImportFromFS(part, baseURL) {
    try {
    if (!part) return false;
    if (typeof(baseURL) == undefined) {
        baseURL = null;
    }

    var resp = new Object();
    resp.include = part.prefset.getStringPref("import_include_matches");
    resp.exclude = part.prefset.getStringPref("import_exclude_matches");
    resp.recursive= part.prefset.getBooleanPref("import_recursive");
    resp.importType= part.prefset.getStringPref("import_type");
    if (part.prefset.hasPrefHere("import_dirname")) {
        resp.dirname = part.prefset.getStringPref("import_dirname");
    } else {
        if (baseURL) {
            resp.dirname = uriparse_URIToLocalPath(baseURL);
        } else {
            resp.dirname = _getPartURL(part);
            if (!resp.dirname) {
                var os = Components.classes["@activestate.com/koOs;1"].getService();
                resp.dirname = os.getcwd();
            }
        }
    }
    resp.res = '';
    resp.part = part;
    resp.global = window;

    openWindowUniqueInstance(
            "chrome://komodo/content/project/importFromFS.xul",
        'komodo_import',
        "chrome,modal,dependent,close=yes",
        resp);
    if (resp.res != true) {
        return false;
    }
    if (resp.include != part.prefset.getStringPref("import_include_matches")) {
        part.prefset.setStringPref("import_include_matches", resp.include);
    }
    if (resp.exclude != part.prefset.getStringPref("import_exclude_matches")) {
        part.prefset.setStringPref("import_exclude_matches", resp.exclude);
    }
    if (resp.recursive != part.prefset.getBooleanPref("import_recursive")) {
        part.prefset.setBooleanPref("import_recursive", resp.recursive);
    }
    if (resp.importType != part.prefset.getStringPref("import_type")) {
        part.prefset.setStringPref("import_type", resp.importType);
    }
    if (resp.dirname != part.prefset.getStringPref("import_dirname")) {
        part.prefset.setStringPref("import_dirname", resp.dirname);
    }
    } catch(e) {
        log.exception(e);
    }
    return true;
}

function part_ImportFromPackage(part, filename) {
    if (!filename)
        filename = filepicker_openFile(
            null, null, // default dir and filename
            "Select Package to Import", // title
            "Komodo Package", // default filter
            ["Komodo Package", "All"]); // filters
            // When have .ktf files changes to this:
            //"Komodo Toolbox", // default filter
            //["Komodo Toolbox", "Komodo Project", "All"]);
    if (!filename) return;

    var basename = uriparse_baseName(filename);
    var directory = filepicker_getFolder(null /* =defaultDirectory */,
                              "Select Directory to extract "+basename+" to" /* =null */);
    if (!directory) return;

    var packager = Components.classes["@activestate.com/koProjectPackageService;1"]
                      .getService(Components.interfaces.koIProjectPackageService);
    packager.importPackage(filename, directory, part)
}
